/****************************************************************************
 * Fragment shader program.  All fragments (AKA potential pixels) pass
 * through this program.
 ****************************************************************************/

/* uniform variables supply a constant value for each fragment
 * passed through the fragment shader.
 */
uniform float uVertexScale;
uniform sampler2D uTexUnit;

/* These varying variables are inputs to the fragment shader.  They are
 * declared as "in" variables in later versions of GLSL.
 */
varying vec2 vTexCoord;
varying vec3 vColor;

void main(void) {
  vec4 color = vec4(vColor.x, vColor.y, vColor.z, 1);
  /* Extract a texel from the texture. */
  vec4 texColor = texture2D(uTexUnit, vTexCoord);

  /* lerp = linear interpolation.  Compute the lerp coefficient. */
  float lerper = .5 * (clamp(.5 *uVertexScale, -1., 1.) + 1.);

  /* gl_FragColor is another GLSL built-in, corresponding to the fragment's
   * color.  Interpolate between the geometry's color and the texture.
   */
  gl_FragColor = lerper*texColor + (1.0-lerper)*color;
}
